import {TablocOptions} from './options.js';

class TablocOptionsPage {
  constructor() {
    this.options = new TablocOptions();
  }

  saveOptions() {
    for (const id of ["fg_foreground",
                      "pos_last",
                      "pos_relative",
                      "ex_inpagelink",
                      "ex_formsubmit"]) {
      this.options.set(id, document.getElementById(id).checked);
    }
    for (const id of ["auto_url_background",
                      "auto_url_foreground",
                      "auto_url_exclude",
                      "ic_emoji"]) {
      this.options.set(id, document.getElementById(id).value);
    }
    this.options.set("auto_url", "");
    for (const id of ["ic_enabled", "ic_disabled"]) {
      this.options.set(id, document.getElementById(id).src);
    }

    const status = document.getElementById("status");
    status.innerText = chrome.i18n.getMessage("options_save_done");
    status.style.display = "";
    setTimeout(() => { status.style.display = "none"; }, 1000);
  }

  restoreLabel(id, msgname) {
    const tag = document.getElementById(id);
    if (tag) {
      tag.innerText = chrome.i18n.getMessage(msgname);
    }
  }

  restoreLabels() {
    for (const id of ["options_head_foreground",
                      "options_fg_background",
                      "options_fg_foreground",
                      "options_head_position",
                      "options_pos_normal",
                      "options_pos_last",
                      "options_pos_relative",
                      "options_head_exclude",
                      "options_ex_inpagelink",
                      "options_ex_formsubmit",
                      "options_head_urls",
                      "options_urls_exclude",
                      "options_head_icon",
                      "options_ic_emoji",
                      "options_ic_enabled",
                      "options_ic_disabled",
                      "options_save"]) {
      this.restoreLabel(id, id);
    }
    this.restoreLabel("options_urls_background",
                      "options_fg_background");
    this.restoreLabel("options_urls_foreground",
                      "options_fg_foreground");
    this.restoreLabel("options_ic_enabled_change",
                      "options_ic_change");
    this.restoreLabel("options_ic_disabled_change",
                      "options_ic_change");
    this.restoreLabel("options_ic_enabled_restore",
                      "options_ic_restore");
    this.restoreLabel("options_ic_disabled_restore",
                      "options_ic_restore");
  }

  restoreOptions() {
    this.options.get("fg_foreground").then(fg_foreground => {
      document.getElementById("fg_background").checked = !fg_foreground;
      document.getElementById("fg_foreground").checked = fg_foreground;
    });

    const pos_last_promise = this.options.get("pos_last");
    const pos_relative_promise = this.options.get("pos_relative");
    pos_last_promise.then(async (pos_last) => {
      const pos_relative = await pos_relative_promise;
      document.getElementById("pos_normal").checked = !pos_last && !pos_relative;
      document.getElementById("pos_last").checked = pos_last;
      document.getElementById("pos_relative").checked = pos_relative;
    });

    for (const id of ["ex_inpagelink", "ex_formsubmit"]) {
      this.options.get(id).then(value => {
        document.getElementById(id).checked = value;
      });
    }

    for (const id of ["auto_url_background",
                      "auto_url_foreground",
                      "auto_url_exclude",
                      "ic_emoji"]) {
      this.options.get(id).then(value => {
        document.getElementById(id).value = value;
      });
    }

    for (const id of ["ic_enabled", "ic_disabled"]) {
      this.options.get(id).then(value => {
        document.getElementById(id).src = value;
      });
    }
  }

  loadImage(id) {
    const file_element = document.getElementById("file_" + id);
    if (!file_element || !(file_element.value) || !file_element.files ||
        !file_element.files[0]){
      return;
    }
    const file_reader = new FileReader();
    file_reader.addEventListener('load', () => {
      document.getElementById(id).setAttribute("src", file_reader.result);
    });
    file_reader.readAsDataURL(file_element.files[0]);
  }

  onLoad() {
    this.restoreLabels();
    this.restoreOptions();
    document.getElementById("options_save").addEventListener("click", () => {
      this.saveOptions();
    });
    document.getElementById("file_ic_enabled").addEventListener("change", () => {
      this.loadImage("ic_enabled");
    });
    document.getElementById("file_ic_disabled").addEventListener("change", () => {
      this.loadImage("ic_disabled");
    });
    document.getElementById("options_ic_enabled_restore").addEventListener("click", () => {
      document.getElementById("file_ic_enabled").value = '';
      document.getElementById("ic_enabled").src = "locked.png";
    });
    document.getElementById("options_ic_disabled_restore").addEventListener("click", () => {
      document.getElementById("file_ic_disabled").value = '';
      document.getElementById("ic_disabled").src = "tabloc.png";
    });
  }
};

window.addEventListener("load", () => {
  new TablocOptionsPage().onLoad();
});
